@@ -18,16 +18,16 @@
 (load "default.scm")
 (load "default-values.scm")
 
+;; I18n
+(textdomain "upmf")
+(setlocale LC_ALL "")
+
 ;; Determine the user startup file
 (define startup-file (getenv "XDG_CONFIG_HOME"))
 (if (eq? startup-file #f)
     (set! startup-file (string-append (getenv "HOME") "/.config/upmf.scm"))
     (set! startup-file (string-append startup-file "/upmf.scm")))
 
-(define unbound-message
-  (lambda ()
-    (errormsg "Undefined variable, aborting" 'fatal)))
-
 ;; Load the user startup file after the default library, so that
 ;; the user can override the default variables
 (if (access? startup-file R_OK)
