@@ -25,6 +25,7 @@
 (load "fetch.scm")
 (load "package.scm")
 (load "patch.scm")
+(load "stow.scm")
 
 (define (_ msg) (gettext msg))
 (define help-message (_ "\
@@ -36,12 +37,19 @@ upmf [options]
   -V, --version                        Display version
   -h, --help                           Display this help
 
+Other options:
+  -b, --bootstrap                      Enable bootstrap mode.  Some
+                                       packages want to be build
+                                       differently when creating a
+                                       toolchain.  That's this option
+                                       is for.
+
 A package string looks like: SECTION/NAME[:VERSION]
 For example: core/autoconf:2.69
 A package group string looks like: NAME
 For example: core, gnome, x11))"))
 (define license-message
-  (string-append "Upmf 0.6.1"
+  (string-append "Upmf 0.7.1\n"
 		 (_ "\
 Copyright (C) 2013 Aljosha Papsch
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.
@@ -52,6 +60,9 @@ There is NO WARRANTY, to the extent permitted by law.")))
 ;; and install-handler displays these strings
 (define installed-packages '())
 
+;; Set whether bootstrap mode is enabled
+(define bootstrap-mode #f)
+
 (define install-package
   (lambda (package-string)
     (if (eq? package-string '())
@@ -67,20 +78,32 @@ There is NO WARRANTY, to the extent permitted by law.")))
 		  (package-obj (load package-file))
 		  (release-to-install (get-release-for package-obj package-release 'verbose))
 		  (extracted-directory (fetch-and-extract (cdr release-to-install)))
-		  (pkg-dest-dir (string-append package-dest-dir "/"
+		  (pkg-base-dir (string-append package-dest-dir "/"
 					       (assq-ref package-obj 'section)
-					       "/" (assq-ref package-obj 'name)
-					       "/" (car release-to-install)))
+					       "/" (assq-ref package-obj 'name)))
+		  (pkg-dest-dir (string-append pkg-base-dir
+					       "/" (car release-to-install)
+					       (if (eq? bootstrap-mode #f)
+						   ""
+						   "-bootstrap")))
 		  (installed-list '())
 		  (current-installed #f))
+	     (if (access? pkg-dest-dir R_OK)
+		 (if (exec (string-append "rm -rf " pkg-dest-dir))
+		     (display "")
+		     (errormsg (_ "Could not wipe installation directory")
+			       pkg-dest-dir)))
 	     (check-dependencies (assq-ref package-obj 'dependencies))
 	     (apply-patches extracted-directory (assq-ref package-obj 'patches)
 			    (car release-to-install))
 	     (if (install-with-mode (assq-ref package-obj 'mode)
-				package-obj extracted-directory
-				pkg-dest-dir)
-		 (set! installed-packages
-		       (append installed-packages (list package-string)))))))))
+				    package-obj extracted-directory
+				    pkg-dest-dir)
+		 (begin (unless (eq? (assq-ref package-obj 'install-info) #f)
+				(install-info pkg-dest-dir))
+			(stow-package pkg-base-dir (car release-to-install))
+			(set! installed-packages
+			      (append installed-packages (list package-string))))))))))
 
 (define remove-package
   (lambda (package-string)
@@ -88,8 +111,16 @@ There is NO WARRANTY, to the extent permitted by law.")))
     (let* ((pkg-and-ver (string-split package-string #\:))
 	   (dir-to-remove (string-append package-dest-dir "/"
 					 (list-ref pkg-and-ver 0) "/"
-					 (list-ref pkg-and-ver 1))))
+					 (list-ref pkg-and-ver 1)))
+	   (package-name (list-ref pkg-and-ver 0))
+	   (package-file (find-package-file package-name))
+	   (package-obj (load package-file))
+	   (pkg-base-dir (string-append package-dest-dir "/"
+					(assq-ref package-obj 'section)
+					"/" (assq-ref package-obj 'name))))
       (statusmsg (_ "Removing package") package-string)
+      (unstow-package pkg-base-dir (list-ref pkg-and-ver 1))
+      ;; remove installation directory
       (if (access? dir-to-remove F_OK)
 	  (statusmsg (_ "Removing directory") dir-to-remove)
 	  (errormsg (_ "Release not installed") package-string 'fatal))
@@ -142,6 +173,7 @@ There is NO WARRANTY, to the extent permitted by law.")))
 			(install-group (single-char #\g) (value #t))
 			(remove (single-char #\r) (value #t))
 			(search (single-char #\s) (value #t))
+			(bootstrap (single-char #\b) (value #f))
 			(version (single-char #\V) (value #f))
 			(help (single-char #\h) (value #f))))
 	 (options (getopt-long (command-line) option-spec))
@@ -149,11 +181,14 @@ There is NO WARRANTY, to the extent permitted by law.")))
 	 (group-wanted (option-ref options 'install-group #f))
 	 (remove-wanted (option-ref options 'remove #f))
 	 (search-wanted (option-ref options 'search #f))
+	 (bootstrap-wanted (option-ref options 'bootstrap #f))
 	 (help-wanted (option-ref options 'help #f))
 	 (version-wanted (option-ref options 'version #f)))
     (if (or install-wanted group-wanted remove-wanted search-wanted
-	    help-wanted version-wanted)
+	    bootstrap-wanted help-wanted version-wanted)
 	(begin
+	  (if bootstrap-wanted
+	      (set! bootstrap-mode #t))
 	  (if remove-wanted
 	      (remove-handler (string-split remove-wanted #\,)))
 	  (if group-wanted
