@@ -55,6 +55,6 @@
 					    archivedir-string "/"
 					    (probe-source-directory archivedir " ")))
 		 (closedir archivedir))
-	  (errormsg (string-append (_ "Archive file not found in distribution directory: ")
-				   archive) 'fatal))
+	  (errormsg (_ "Archive file not found in distribution directory: ")
+		    archive 'fatal))
       extracted-directory)))
