@@ -19,12 +19,12 @@
   (lambda (directory patchlist for-version)
     (let ((cur-patch #f))
       (if (eq? patchlist #f)
-	  (display ">> No patches for this package\n")
+	  (statusmsg (_ "No patches for this package"))
 	  (begin
 	    (do ((k 0 (1+ k)))
 		((> k (- (length patchlist) 1)))
 	      (set! cur-patch (list-ref patchlist k))
 	      (if (eq? (list-ref cur-patch 0) #f)
-		  (display ">> No patches for this package\n")
+		  (statusmsg (_ "No patches for this package"))
 		  (if (member for-version (assq-ref cur-patch 'for-version))
 		      (patch directory (assq-ref cur-patch 'name))))))))))
